@@ -38,9 +38,9 @@ public:
                              ElisaUtils::Track,
                              Qt::DisplayRole,
                              {Qt::DisplayRole},
-                             {i18n("Title")},
+                             {i18nc("@title:inmenu", "Title")},
                              Qt::AscendingOrder,
-                             {i18n("A-Z"), i18n("Z-A")},
+                             {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                              ViewManager::SingleAlbum,
                              ViewManager::DiscHeaders,
                              ViewManager::IsTrack,
@@ -53,9 +53,9 @@ public:
                              ElisaUtils::Artist,
                              Qt::DisplayRole,
                              {Qt::DisplayRole},
-                             {i18n("Name")},
+                             {i18nc("@title:inmenu", "Name")},
                              Qt::AscendingOrder,
-                             {i18n("A-Z"), i18n("Z-A")},
+                             {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                              QUrl{QStringLiteral("image://icon/view-media-artist")},
                              ViewManager::DelegateWithoutSecondaryText,
                              ViewManager::ViewHideRating,
@@ -68,9 +68,9 @@ public:
                               ElisaUtils::Album,
                               DataTypes::TitleRole,
                               {DataTypes::TitleRole, DataTypes::GenreRole, DataTypes::YearRole},
-                              {i18n("Title"), i18n("Genre"), i18n("Year")},
+                              {i18nc("@title:inmenu", "Title"), i18nc("@title:inmenu", "Genre"), i18nc("@title:inmenu", "Year")},
                               Qt::AscendingOrder,
-                              {i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("Oldest First"), i18n("Newest First")},
+                              {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First")},
                               QUrl{QStringLiteral("image://icon/media-default-album")},
                               ViewManager::DelegateWithSecondaryText,
                               ViewManager::ViewShowRating,
@@ -83,9 +83,9 @@ public:
                                  ElisaUtils::FileName,
                                  Qt::DisplayRole,
                                  {Qt::DisplayRole},
-                                 {i18n("Name")},
+                                 {i18nc("@title:inmenu", "Name")},
                                  Qt::AscendingOrder,
-                                 {i18n("A-Z"), i18n("Z-A")},
+                                 {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                                  QUrl{QStringLiteral("image://icon/folder")},
                                  ViewManager::DelegateWithoutSecondaryText,
                                  ViewManager::ViewHideRating,
